@@ -36,7 +36,7 @@ use vars qw/ $VERSION $DEBUG @ISA /;
 use Exporter 'import';
 our @EXPORT_OK = qw( translate_from_FITS translate_to_FITS );
 
-$VERSION = '1.57';
+$VERSION = '1.58';
 $DEBUG   = 0;
 
 # The reference list of classes we can try This list should be
@@ -157,10 +157,12 @@ my @generic_headers = qw(
                           SAMPLE_MODE
                           SAMPLING
                           SCAN_INCREMENT
+                          SCAN_PATTERN
                           SEEING
                           SLIT_ANGLE
                           SLIT_NAME
                           SLIT_WIDTH
+                          SPECIES
                           SPEED_GAIN
                           STANDARD
                           SUBSYSTEM_IDKEY
@@ -171,6 +173,7 @@ my @generic_headers = qw(
                           TAU
                           TELESCOPE
                           TILE_NUMBER
+                          TRANSITION
                           USER_AZIMUTH_CORRECTION
                           USER_ELEVATION_CORRECTION
                           UTDATE
