@@ -36,7 +36,7 @@ use constant CLIGHT => 2.99792458e5;
 
 use vars qw/ $VERSION /;
 
-$VERSION = "1.57";
+$VERSION = "1.58";
 
 # Cache UTC definition
 our $UTC = DateTime::TimeZone->new( name => 'UTC' );
@@ -52,7 +52,7 @@ my %CONST_MAP = (
                  INST_DHS          => 'ACSIS',
                 );
 
-# unit mapping implies that the value propogates directly
+# unit mapping implies that the value propagates directly
 # to the output with only a keyword name change
 
 my %UNIT_MAP = (
@@ -68,8 +68,8 @@ my %UNIT_MAP = (
                 ELEVATION_END      => 'ELEND',
                 FRONTEND           => 'INSTRUME',
                 NUMBER_OF_CYCLES   => 'NUM_CYC',
-                SEEING             => 'SEEINGST',
                 SWITCH_MODE        => 'SW_MODE',
+                SPECIES            => 'MOLECULE',
                 VELOCITY_TYPE      => 'DOPPLER',
                );
 
@@ -565,6 +565,52 @@ sub to_SYSTEM_VELOCITY {
   return $return;
 }
 
+=item B<to_TRANSITION>
+
+Converts the TRANSITI header to the TRANSITION generic header.
+
+This would be a unit mapping except that we would like to tidy up
+some whitespace issues.
+
+=cut
+
+sub to_TRANSITION {
+    my $self = shift;
+    my $FITS_headers = shift;
+
+    my $transition = $FITS_headers->{'TRANSITI'};
+
+    return undef unless defined $transition;
+
+    # Remove leading and trailing spaces.
+    $transition =~ s/^ *//;
+    $transition =~ s/ *$//;
+    # Remove duplicated spaces.
+    $transition =~ s/  +/ /g;
+
+    return $transition;
+}
+
+=item B<from_TRANSITION>
+
+Converts TRANSITION back to TRANSITI.
+
+=cut
+
+sub from_TRANSITION {
+    my $self = shift;
+    my $generic_headers = shift;
+
+    my $transition = $generic_headers->{'TRANSITION'};
+
+    if (defined $transition) {
+        # Restore whitespace issue to allow comparison of untranslated header.
+        $transition =~ s/ - /  - /;
+    }
+
+    return (TRANSITI => $transition);
+}
+
 =item B<to_VELOCITY>
 
 Converts the ZSOURCE header into an appropriate system velocity,
@@ -663,11 +709,6 @@ sub _is_FSW {
 
 =back
 
-
-=head1 REVISION
-
- $Id$
-
 =head1 SEE ALSO
 
 C<Astro::FITS::HdrTrans>, C<Astro::FITS::HdrTrans::Base>
@@ -679,6 +720,7 @@ Brad Cavanagh E<lt>b.cavanagh@jach.hawaii.eduE<gt>.
 
 =head1 COPYRIGHT
 
+Copyright (C) 2016 East Asian Observatory.
 Copyright (C) 2007-2008 Science and Technology Facilities Council.
 Copyright (C) 2005-2007 Particle Physics and Astronomy Research Council.
 All Rights Reserved.
