@@ -14,7 +14,7 @@ use Astro::Telescope;
 use DateTime;
 use DateTime::TimeZone;
 
-our $VERSION = '1.57';
+our $VERSION = '1.58';
 
 use base qw/ Astro::FITS::HdrTrans::JAC /;
 
@@ -33,6 +33,7 @@ my %UNIT_MAP =
     OBJECT               => 'OBJECT',
     OBSERVATION_NUMBER   => 'OBSNUM',
     PROJECT              => 'PROJECT',
+    SCAN_PATTERN         => 'SCAN_PAT',
     STANDARD             => 'STANDARD',
     X_APERTURE           => 'INSTAP_X',
     Y_APERTURE           => 'INSTAP_Y',
@@ -186,6 +187,38 @@ sub to_TAU {
   return $tau;
 }
 
+=item B<to_SEEING>
+
+Use the average seeing measurements.
+
+=cut
+
+sub to_SEEING {
+  my $self = shift;
+  my $FITS_headers = shift;
+
+  my $seeing = 0.0;
+
+
+  my @startvals = $self->via_subheader_undef_check( $FITS_headers, "SEEINGST" );
+  my @endvals   = $self->via_subheader_undef_check( $FITS_headers, "SEEINGEN" );
+  my $startval = $startvals[0];
+  my $endval = $endvals[-1];
+
+  if (defined $startval && defined $endval) {
+      $seeing = ($startval + $endval) / 2;
+  } elsif (defined $startval) {
+      $seeing = $startval;
+  } elsif (defined $endval) {
+      $seeing = $endval;
+  }
+
+  return $seeing;
+}
+
+
+
+
 =item B<to_OBSERVATION_ID_SUBSYSTEM>
 
 Returns the subsystem observation IDs associated with the header.
@@ -350,6 +383,7 @@ Tim Jenness E<lt>t.jenness@jach.hawaii.eduE<gt>.
 =head1 COPYRIGHT
 
 Copyright (C) 2009 Science and Technology Facilities Council.
+Copyright (C) 2016 East Asian Observatory.
 All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it under
